==> discover-5.18.2.tar.xz: discover-5.18.2/libdiscover/backends/FlatpakBackend/FlatpakSourcesBackend.h <==
/***************************************************************************
 *   Copyright © 2014 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
 *   Copyright © 2017 Jan Grulich <jgrulich@redhat.com>                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef FLATPAKSOURCESBACKEND_H
#define FLATPAKSOURCESBACKEND_H

#include <resources/AbstractSourcesBackend.h>
#include <QStandardItemModel>

extern "C" {
#include <flatpak.h>
}

class FlatpakResource;
class FlatpakSourcesBackend : public AbstractSourcesBackend
{
Q_OBJECT
public:
    explicit FlatpakSourcesBackend(const QVector<FlatpakInstallation *>& installations, AbstractResourcesBackend *parent);
    ~FlatpakSourcesBackend() override;

    QAbstractItemModel* sources() override;
    bool addSource(const QString &id) override;
    bool removeSource(const QString &id) override;
    QString idDescription() override;
    QVariantList actions() const override;
    bool supportsAdding() const override { return true; }
    bool canFilterSources() const override { return true; }

    FlatpakRemote * installSource(FlatpakResource *resource);
    bool canMoveSources() const override { return true; }

    bool moveSource(const QString & sourceId, int delta) override;
    int originIndex(const QString& sourceId) const;
    QStandardItem* sourceByUrl(const QString & url) const;

private:
    QStandardItem* sourceById(const QString & sourceId) const;
    bool listRepositories(FlatpakInstallation *installation);
    void addRemote(FlatpakRemote *remote, FlatpakInstallation *installation);

    FlatpakInstallation *m_preferredInstallation;
    QStandardItemModel* m_sources;
    QAction* const m_flathubAction;
    QStandardItem* m_noSourcesItem;
};

#endif // FLATPAKSOURCESBACKEND_H

==> discover-5.20.90.tar.xz: discover-5.20.90/libdiscover/backends/FlatpakBackend/FlatpakSourcesBackend.h <==
/*
 *   SPDX-FileCopyrightText: 2014 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
 *   SPDX-FileCopyrightText: 2017 Jan Grulich <jgrulich@redhat.com>
 *
 *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */

#ifndef FLATPAKSOURCESBACKEND_H
#define FLATPAKSOURCESBACKEND_H

#include <resources/AbstractSourcesBackend.h>
#include <QStandardItemModel>
#include <QStack>
#include <functional>

extern "C" {
#include <flatpak.h>
}

class FlatpakResource;
class FlatpakSourcesBackend : public AbstractSourcesBackend
{
Q_OBJECT
public:
    explicit FlatpakSourcesBackend(const QVector<FlatpakInstallation *>& installations, AbstractResourcesBackend *parent);
    ~FlatpakSourcesBackend() override;

    enum Roles { IconUrlRole = LastRole + 1 };

    QAbstractItemModel* sources() override;
    bool addSource(const QString &id) override;
    bool removeSource(const QString &id) override;
    QString idDescription() override;
    QVariantList actions() const override;
    bool supportsAdding() const override { return true; }
    bool canFilterSources() const override { return true; }

    FlatpakRemote * installSource(FlatpakResource *resource);
    bool canMoveSources() const override { return true; }

    bool moveSource(const QString & sourceId, int delta) override;
    int originIndex(const QString& sourceId) const;
    QStandardItem* sourceByUrl(const QString & url) const;
    QStandardItem* sourceById(const QString & sourceId) const;

    void cancel() override;
    void proceed() override;

private:
    bool listRepositories(FlatpakInstallation *installation);
    void addRemote(FlatpakRemote *remote, FlatpakInstallation *installation);

    FlatpakInstallation *m_preferredInstallation;
    QStandardItemModel* m_sources;
    QAction* const m_flathubAction;
    QStandardItem* m_noSourcesItem;
    QStack<std::function<void()>> m_proceedFunctions;
};

#endif // FLATPAKSOURCESBACKEND_H
